#!/bin/sh

# ARGS:
# $1 : path to N4 app resource dir
# $2 : install AU
# $3 : install VST
# $4 : install RW (propellerheads driver)
# $5 : install RWD (n4 rwd)
# $6 : is snow leopard
# $7 : is mavericks
# $8 : move mindvision
# $9 : is high sierra


if $2
then

	echo "** Numerology 4 Install Audio Unit **"

	# delete existing AU
	if [ -e '/Library/Audio/Plug-Ins/Components/NumerologyAU.component' ]
	then
		echo ".. prev AU exists"
		rm -r '/Library/Audio/Plug-Ins/Components/NumerologyAU.component';
	fi

	# copy in N4 AU
  if $9
  then
	# NOTE: copy of new AU disabled until issues w/ OS X 10.13 & Logic/Mainstage are resolved
	echo "** Skip AU Install for Newer OS X **"
  else
	cp -r "$1/NumerologyAU.zip" '/Library/Audio/Plug-Ins/Components/'
	cd '/Library/Audio/Plug-Ins/Components'
	unzip -o NumerologyAU.zip
	rm NumerologyAU.zip
  fi

fi

if $7
then

	echo "** Numerology 4 Install Audio Unit MIDI Effect**"

	# delete existing AUMX
	if [ -e '/Library/Audio/Plug-Ins/Components/NumerologyAUMX.component' ]
	then
		echo ".. prev AUMX exists"
		rm -r '/Library/Audio/Plug-Ins/Components/NumerologyAUMX.component';
	fi

	# copy in N4 AUMX
	cp -r "$1/NumerologyAUMX.zip" '/Library/Audio/Plug-Ins/Components/'
	cd '/Library/Audio/Plug-Ins/Components'
	unzip -o NumerologyAUMX.zip
	rm NumerologyAUMX.zip
	
fi




if $3
then

	echo "** Numerology 4 Install VST **"

	# delete existing VST
	if [ -e '/Library/Audio/Plug-Ins/VST/NumerologyVST.zip' ]
	then
		echo ".. prev VST exists"
		rm -r '/Library/Audio/Plug-Ins/VST/NumerologyVST.zip';
	fi

	# copy in N4 VST
	cp -r "$1/NumerologyVST.zip" '/Library/Audio/Plug-Ins/VST/'
	cd '/Library/Audio/Plug-Ins/VST'
	unzip -o NumerologyVST.zip
	rm NumerologyVST.zip

fi


if $4
then

	echo "** Numerology 4 Install Propellerheads Rewire **"

	if [ -e '/Library/Application Support/Propellerhead Software' ]
	then
  		echo ".. Propellerhead dir exists"
	else 
		echo ".. no Propellerhead dir"
	    mkdir '/Library/Application Support/Propellerhead Software'
	fi

	if [ -e '/Library/Application Support/Propellerhead Software/ReWire' ]
	then
		echo ".. ReWire dir exists"
	else
		echo ".. no ReWire dir"
	    mkdir '/Library/Application Support/Propellerhead Software/ReWire'
	fi

		echo ".. ReWire 10.7 & Later Install (ReWire.bundle v1.8.7)"

  		if [ -e '/Library/Application Support/Propellerhead Software/ReWire/ReWire.bundle' ]
		then
			echo ".. ReWire bundle exists (remove)"
			rm -r '/Library/Application Support/Propellerhead Software/ReWire/ReWire.bundle'
		fi

		echo ".. copy ReWire bundle: $1"
		cp -r "$1/ReWire.bundle" '/Library/Application Support/Propellerhead Software/ReWire'
         fi

if $5 
then

	echo "** Numerology 4 Install Remove Old Rewire Drivers **"

	# delete N2 RWD
	if [ -e '/Library/Application Support/Propellerhead Software/ReWire/NumerologyReWireDevice.plugin' ]
	then
		echo ".. N3 RWD exists"
		rm -r '/Library/Application Support/Propellerhead Software/ReWire/NumerologyReWireDevice.plugin';
	fi

	# delete N3 RWD
	if [ -e '/Library/Application Support/Propellerhead Software/ReWire/Numerology3ReWireDevice.plugin' ]
	then
		echo ".. N3 RWD exists"
		rm -r '/Library/Application Support/Propellerhead Software/ReWire/Numerology3ReWireDevice.plugin';
	fi

	echo "** Numerology 4 Install: Numerology 4 Rewire Driver **"

	# always copy in N4 RWD
	cp -r "$1/Numerology4ReWireDevice.plugin" '/Library/Application Support/Propellerhead Software/ReWire/'

fi


# if not snow leopard and mindvision folder exists, rename it
if $8
then

	echo "** Numerology 4 Install: Check Move Mindvision **"

	if [ -e '/Library/Application Support/MindVision' ]
	then
		mv '/Library/Application Support/MindVision' '/Library/Application Support/MindVision-OLD'
	fi


fi
